@@ -1208,11 +1208,7 @@ game_about_callback (GtkAction * action, gpointer * data)
   gchar *license = games_get_license (_("Five or More"));
 
   gtk_show_about_dialog (GTK_WINDOW (app),
-#if GTK_CHECK_VERSION (2, 11, 0)
                          "program-name", _("Five or More"),
-#else
-                         "name", _("Five or More"),
-#endif
                          "version", VERSION,
                          "comments", _("GNOME port of the once-popular Color Lines game.\n\nFive or More is a part of GNOME Games."),
                          "copyright",
@@ -1742,10 +1738,7 @@ main (int argc, char *argv[])
   rgen = g_rand_new ();
 
   context = g_option_context_new (NULL);
-#if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif
-
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 #ifdef WITH_SMCLIENT
   g_option_context_add_group (context, egg_sm_client_get_option_group ());
