@@ -82,7 +82,6 @@ static const GamesScoresCategory scorecats[] = {
 
 GamesScores *highscores;
 
-extern GdkPixmap *buffer_pixmap;
 extern GdkPixbuf *logo_pixmap;
 
 GnibblesProperties *properties;
@@ -197,11 +196,7 @@ about_cb (GtkAction * action, gpointer data)
   gchar *license = games_get_license (_("Nibbles"));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-#if GTK_CHECK_VERSION (2, 11, 0)
        "program-name", _("Nibbles"),
-#else
-       "name", _("Nibbles"),
-#endif
        "version", VERSION,
        "copyright",
        "Copyright \xc2\xa9 1999-2008 Sean MacIsaac, Ian Peters, Andreas Røsdal"
@@ -1008,12 +1003,9 @@ main (int argc, char **argv)
 #endif
 
   gtk_clutter_init (&argc, &argv);
+
   context = g_option_context_new (NULL);
-
-#if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif
-
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
