@@ -517,18 +517,14 @@ update_arena (void)
       if ((temp_arena[i][j] == OBJECT_HEAP) &&
 	  (push_xpos == i) && (push_ypos == j)) {
 	if (arena[i][j] == OBJECT_ROBOT1) {
-	  if (properties_splats ()) {
-	    add_splat_bubble (i, j);
-	    play_sound (SOUND_SPLAT);
-	  }
+	  add_splat_bubble (i, j);
+	  play_sound (SOUND_SPLAT);
 	  push_xpos = push_ypos = -1;
 	  score += game_config ()->score_type1_splatted;
 	}
 	if (arena[i][j] == OBJECT_ROBOT2) {
-	  if (properties_splats ()) {
-	    add_splat_bubble (i, j);
-	    play_sound (SOUND_SPLAT);
-	  }
+	  add_splat_bubble (i, j);
+	  play_sound (SOUND_SPLAT);
 	  push_xpos = push_ypos = -1;
 	  score += game_config ()->score_type2_splatted;
 	}
@@ -673,7 +669,7 @@ init_game (void)
 {
   create_game_timer ();
 
-  g_signal_connect (GTK_OBJECT (app), "key_press_event",
+  g_signal_connect (GTK_WIDGET (app), "key_press_event",
 		    G_CALLBACK (keyboard_cb), 0);
 
   start_new_game ();
@@ -1474,7 +1470,7 @@ move_cb (GtkWidget * widget, GdkEventMotion * e, gpointer data)
 
   get_dir (e->x, e->y, &dx, &dy);
 
-  set_cursor_by_direction (widget->window, dx, dy);
+  set_cursor_by_direction (gtk_widget_get_window (widget), dx, dy);
 
   return TRUE;
 }
