@@ -35,11 +35,14 @@
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-frame.h>
+#include <libgames-support/games-gtk-compat.h>
 #include <libgames-support/games-help.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.c>
 #include <libgames-support/games-scores-dialog.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-pause-action.h>
+#include <libgames-support/games-fullscreen-action.h>
 
 #ifdef WITH_SMCLIENT
 #include <libgames-support/eggsmclient.h>
@@ -87,13 +90,10 @@ gint fsize = -1;
 gboolean use_question_marks = TRUE;
 gboolean use_overmine_warning = TRUE;
 gboolean use_autoflag = FALSE;
-gboolean game_paused = FALSE;
 
 GtkAction *hint_action;
 GtkAction *fullscreen_action;
-GtkAction *leavefullscreen_action;
 GtkAction *pause_action;
-GtkAction *resume_action;
 
 /*GstElement *sound_player;*/
 
@@ -262,16 +262,19 @@ new_game (void)
   gint x, y;
   static gint size_table[3][3] = { {8, 8, 10}, {16, 16, 40}, {30, 16, 99} };
   GtkMineField *mf = GTK_MINEFIELD (mfield);
+  GtkAllocation allocation;
 
   games_clock_stop (GAMES_CLOCK (clk));
   games_clock_reset (GAMES_CLOCK (clk));
   show_face (pm_smile);
 
+
   /* get window size and mine square size (gtk_minefield_restart() may change it) */
   gtk_window_get_size (GTK_WINDOW (window), &width, &height);
   size = mf->minesizepixels;
-  w_diff = width - mfield->allocation.width;
-  h_diff = height - mfield->allocation.height;
+  gtk_widget_get_allocation (mfield, &allocation);
+  w_diff = width - allocation.width;
+  h_diff = height - allocation.height;
 
   if (fsize == 3) {
     x = xsize;
@@ -289,8 +292,7 @@ new_game (void)
 
   set_flabel (GTK_MINEFIELD (mfield));
 
-  gtk_action_set_visible (pause_action, TRUE);
-  gtk_action_set_visible (resume_action, FALSE);
+  gtk_action_set_sensitive (pause_action, TRUE);
   gtk_widget_hide (resume_container);
   gtk_widget_show (mfield_container);
 }
@@ -321,12 +323,11 @@ hint_callback (void)
   else
     message = _("Maybe they're all mines ...");
 
-  dialog = gtk_message_dialog_new (GTK_WINDOW (window), GTK_DIALOG_MODAL,
-				   GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-				   message, NULL);
+  dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window),
+                                               GTK_DIALOG_MODAL,
+                                               GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+                                               message, NULL);
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-  gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label),
-			    TRUE);
 
   disable_hiding = TRUE;
   gtk_dialog_run (GTK_DIALOG (dialog));
@@ -336,41 +337,35 @@ hint_callback (void)
 }
 
 static void
-pause_callback (GtkWidget * widget, GdkEventFocus * event, gpointer data)
+pause_callback (GtkAction * action, gpointer data)
 {
-  if (games_clock_is_started (GAMES_CLOCK (clk))
-      && (!disable_hiding)) {
+  if (games_pause_action_get_is_paused (GAMES_PAUSE_ACTION (pause_action))) {
     gtk_widget_hide (mfield_container);
     gtk_widget_show (resume_container);
     gtk_widget_grab_focus (resume_button);
-
+  
     gtk_action_set_sensitive (hint_action, FALSE);
     games_clock_stop (GAMES_CLOCK (clk));
-
-    gtk_action_set_visible (pause_action, FALSE);
-    gtk_action_set_sensitive (pause_action, FALSE);
-
-    gtk_action_set_visible (resume_action, TRUE);
-    gtk_action_set_sensitive (resume_action, TRUE);
-
-    game_paused = TRUE;
+  }
+  else {
+    gtk_widget_hide (resume_container);
+    gtk_widget_show (mfield_container);
+    gtk_action_set_sensitive (hint_action, TRUE);
+    games_clock_start (GAMES_CLOCK (clk));
   }
 }
 
 static void
-resume_game_cb (GtkButton * widget, gpointer data)
+focus_out_callback (GtkWidget * widget, GdkEventFocus * event, gpointer data)
 {
-  gtk_widget_hide (resume_container);
-  gtk_widget_show (mfield_container);
-  gtk_action_set_sensitive (hint_action, TRUE);
-  games_clock_start (GAMES_CLOCK (clk));
+  if (games_clock_is_started (GAMES_CLOCK (clk)) && (!disable_hiding))
+    games_pause_action_set_is_paused (GAMES_PAUSE_ACTION (pause_action), TRUE);
+}
 
-  gtk_action_set_visible (pause_action, TRUE);
-  gtk_action_set_sensitive(pause_action, TRUE);
-  gtk_action_set_visible (resume_action, FALSE);
-  gtk_action_set_sensitive(resume_action, FALSE);
-
-  game_paused = FALSE;
+static void
+resume_game_cb (GtkWidget * widget, GdkEventFocus * event, gpointer data)
+{
+  games_pause_action_set_is_paused (GAMES_PAUSE_ACTION (pause_action), FALSE);
 }
 
 static void
@@ -616,54 +611,6 @@ use_overmine_toggle_cb (GtkCheckButton * check, gpointer data)
   games_conf_set_boolean (NULL, KEY_USE_OVERMINE_WARNING, use_overmine);
 }
 
-static void
-set_fullscreen_actions (gboolean is_fullscreen)
-{
-  gtk_action_set_sensitive (leavefullscreen_action, is_fullscreen);
-  gtk_action_set_visible (leavefullscreen_action, is_fullscreen);
-
-  gtk_action_set_sensitive (fullscreen_action, !is_fullscreen);
-  gtk_action_set_visible (fullscreen_action, !is_fullscreen);
-}
-
-static void
-fullscreen_callback (GtkAction * action)
-{
-  if (action == fullscreen_action)
-    gtk_window_fullscreen (GTK_WINDOW (window));
-  else
-    gtk_window_unfullscreen (GTK_WINDOW (window));
-}
-
-static gboolean
-window_state_callback (GtkWidget * widget, GdkEventWindowState * event)
-{
-  if (!(event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN))
-    return FALSE;
-
-  set_fullscreen_actions (event->
-			  new_window_state & GDK_WINDOW_STATE_FULLSCREEN);
-    
-  return FALSE;
-}
-
-
-static void
-pause_key_callback(GtkWidget *widget, GdkEventKey *event,
-gpointer data )
-{
-
-  if(event->keyval == GDK_Pause)
-  {
-    if(game_paused)
-      resume_game_cb(NULL, NULL); // Resume the game
-    else
-      pause_callback(NULL, NULL, NULL); // Pause the game
-  }
-			
-}
-
-
 static void
 create_preferences (void)
 {
@@ -791,12 +738,11 @@ create_preferences (void)
 					     GTK_STOCK_CLOSE,
 					     GTK_RESPONSE_CLOSE, NULL);
 
-  gtk_dialog_set_has_separator (GTK_DIALOG (pref_dialog), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (pref_dialog))), 2);
   gtk_window_set_resizable (GTK_WINDOW (pref_dialog), FALSE);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), table, FALSE,
-		      FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (pref_dialog))),
+                      table, FALSE, FALSE, 0);
 
   g_signal_connect (G_OBJECT (pref_dialog), "destroy",
 		    G_CALLBACK (gtk_widget_destroyed), &pref_dialog);
@@ -827,10 +773,6 @@ const GtkActionEntry actions[] = {
   {"SettingsMenu", NULL, N_("_Settings")},
   {"HelpMenu", NULL, N_("_Help")},
   {"NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (new_game)},
-  {"PauseGame", GAMES_STOCK_PAUSE_GAME, NULL, NULL, NULL,
-   G_CALLBACK (pause_callback)},
-  {"ResumeGame", GAMES_STOCK_RESUME_GAME, NULL, NULL, NULL,
-   G_CALLBACK (resume_game_cb)},
   {"Hint", GAMES_STOCK_HINT, NULL, NULL, NULL, G_CALLBACK (hint_callback)},
   {"Scores", GAMES_STOCK_SCORES, NULL, NULL, NULL,
    G_CALLBACK (scores_callback)},
@@ -839,11 +781,7 @@ const GtkActionEntry actions[] = {
    G_CALLBACK (preferences_callback)},
   {"Contents", GAMES_STOCK_CONTENTS, NULL, NULL, NULL,
    G_CALLBACK (help_callback)},
-  {"About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (about_callback)},
-  {"Fullscreen", GAMES_STOCK_FULLSCREEN, NULL, NULL, NULL,
-   G_CALLBACK (fullscreen_callback)},
-  {"LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL,
-   G_CALLBACK (fullscreen_callback)}
+  {"About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (about_callback)}
 };
 
 const char ui_description[] =
@@ -853,7 +791,6 @@ const char ui_description[] =
   "      <menuitem action='NewGame'/>"
   "      <menuitem action='Hint'/>"
   "      <menuitem action='PauseGame'/>"
-  "      <menuitem action='ResumeGame'/>"
   "      <separator/>"
   "      <menuitem action='Scores'/>"
   "      <separator/>"
@@ -861,12 +798,14 @@ const char ui_description[] =
   "    </menu>"
   "    <menu action='SettingsMenu'>"
   "      <menuitem action='Fullscreen'/>"
-  "      <menuitem action='LeaveFullscreen'/>"
   "      <menuitem action='Preferences'/>"
   "    </menu>"
   "    <menu action='HelpMenu'>"
   "      <menuitem action='Contents'/>"
-  "      <menuitem action='About'/>" "    </menu>" "  </menubar>" "</ui>";
+  "      <menuitem action='About'/>"
+  "    </menu>"
+  "  </menubar>"
+  "</ui>";
 
 static GtkUIManager *
 create_ui_manager (const gchar * group)
@@ -884,15 +823,12 @@ create_ui_manager (const gchar * group)
   gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL);
   hint_action = gtk_action_group_get_action (action_group, "Hint");
 
-  fullscreen_action =
-    gtk_action_group_get_action (action_group, "Fullscreen");
-  leavefullscreen_action =
-    gtk_action_group_get_action (action_group, "LeaveFullscreen");
-  set_fullscreen_actions (FALSE);
+  fullscreen_action = GTK_ACTION (games_fullscreen_action_new ("Fullscreen", GTK_WINDOW (window)));
+  gtk_action_group_add_action_with_accel (action_group, fullscreen_action, NULL);
 
-  pause_action = gtk_action_group_get_action (action_group, "PauseGame");
-  resume_action = gtk_action_group_get_action (action_group, "ResumeGame");
-  gtk_action_set_visible (resume_action, FALSE);
+  pause_action = GTK_ACTION (games_pause_action_new ("PauseGame"));
+  g_signal_connect (G_OBJECT (pause_action), "state-changed", G_CALLBACK (pause_callback), NULL);
+  gtk_action_group_add_action_with_accel (action_group, pause_action, NULL);
 
   return ui_manager;
 }
@@ -907,7 +843,7 @@ save_state_cb (EggSMClient *client,
   int argc = 0, j;
   gint xpos, ypos;
 
-  gdk_window_get_origin (window->window, &xpos, &ypos);
+  gdk_window_get_origin (gtk_widget_get_window (window), &xpos, &ypos);
 
   argv[argc++] = g_get_prgname ();
   argv[argc++] = "-x";
@@ -1068,12 +1004,6 @@ main (int argc, char *argv[])
 
   verify_ranges ();
 
-  /* This is evil, but the normal button focus indicator 
-   * interferes with the face (but we still want the button
-   * to be the default). */
-  gtk_rc_parse_string
-    ("style \"gnomine\" { GtkButton::interior-focus = 0 } class \"GtkButton\" style \"gnomine\"");
-
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), _(APP_NAME_LONG));
     
@@ -1086,15 +1016,10 @@ main (int argc, char *argv[])
   g_signal_connect (G_OBJECT (window), "delete_event",
 		    G_CALLBACK (quit_game), NULL);
   g_signal_connect (G_OBJECT (window), "focus_out_event",
-		    G_CALLBACK (pause_callback), NULL);
-  g_signal_connect (G_OBJECT (window), "window_state_event",
-		    G_CALLBACK (window_state_callback), NULL);
-
-  // For pause/resume with the keyboard pause key
-  g_signal_connect (G_OBJECT (window), "key_press_event", 
-                    G_CALLBACK (pause_key_callback), NULL); 
+		    G_CALLBACK (focus_out_callback), NULL);
 
   all_boxes = gtk_vbox_new (FALSE, 0);
+  gtk_widget_show (all_boxes);
 
   gtk_container_add (GTK_CONTAINER (window), all_boxes);
 
@@ -1102,6 +1027,7 @@ main (int argc, char *argv[])
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
   box = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
+  gtk_widget_show (box);
   gtk_box_pack_start (GTK_BOX (all_boxes), box, FALSE, FALSE, 0);
 
   button_table = gtk_table_new (1, 3, FALSE);
@@ -1190,11 +1116,12 @@ main (int argc, char *argv[])
 
   new_game ();
 
-  gtk_widget_show_all (window);
+  gtk_widget_show_all (button_table);
+  gtk_widget_show (window);
 
   /* Must be after the window has been created. */
   if (xpos >= 0 && ypos >= 0)
-    gdk_window_move (GTK_WIDGET (window)->window, xpos, ypos);
+    gdk_window_move (gtk_widget_get_window (GTK_WIDGET (window)), xpos, ypos);
 
   /* All this hiding is a bit ugly, but it's better than a
    * ton of gtk_widget_show calls. */
